translate.misc.textwrap.TextWrapper

Package translate :: Package misc :: Module textwrap :: Class TextWrapper |
[hide private]
[frames] | no frames]

# Class TextWrapper

source code

    Object for wrapping/filling text.  The public interface consists of
    the wrap() and fill() methods; the other methods are just there for
    subclasses to override in order to tweak the default behaviour.
    If you want to completely replace the main wrapping algorithm,
    you'll probably have to override _wrap_chunks().

    Several instance attributes control various aspects of wrapping:
      width (default: 70)
        the maximum width of wrapped lines (unless break_long_words
        is false)
      initial_indent (default: "")
        string that will be prepended to the first line of wrapped
        output.  Counts towards the line's width.
      subsequent_indent (default: "")
        string that will be prepended to all lines save the first
        of wrapped output; also counts towards each line's width.
      expand_tabs (default: true)
        Expand tabs in input text to spaces before further processing.
        Each tab will become 1 .. 8 spaces, depending on its position in
        its line.  If false, each tab is treated as a single character.
      drop_whitespace (default: true)
        Drop leading and trailing whitespace from lines.
      replace_whitespace (default: true)
        Replace all whitespace characters in the input text by spaces
        after tab expansion.  Note that if expand_tabs is false and
        replace_whitespace is true, every tab will be converted to a
        single space!
      fix_sentence_endings (default: false)
        Ensure that sentence-ending punctuation is always followed
        by two spaces.  Off by default because the algorithm is
        (unavoidably) imperfect.
      break_long_words (default: true)
        Break words longer than 'width'.  If false, those words will not
        be broken, and some lines might be longer than 'width'.

Instance Methods | [hide private]
__init__(self, width=70, initial_indent=`'````'`, subsequent_indent=`'````'`, expand_tabs=True, drop_whitespace=True, replace_whitespace=True, fix_sentence_endings=False, break_long_words=True) | source code
_munge_whitespace(self, text) _munge_whitespace(text : string) -> string | source code
_split(self, text) _split(text : string) -> [string] | source code
_fix_sentence_endings(self, chunks) _fix_sentence_endings(chunks : [string]) | source code
_handle_long_word(self, reversed_chunks, cur_line, cur_len, width) _handle_long_word(chunks : [string], cur_line : [string], cur_len : int, width : int) | source code
_wrap_chunks(self, chunks) _wrap_chunks(chunks : [string]) -> [string] | source code
wrap(self, text) wrap(text : string) -> [string] | source code
fill(self, text) fill(text : string) -> string | source code

Class Variables | [hide private]
| whitespace_trans = ``'``\x00\x01\x02\x03\x04\x05\x06\x07\x08 \``...``
| unicode_whitespace_trans = ``{`9`:` 32`,` 10`:` 32`,` 11`:` 32`,` 12`:` 32`,` 13`:``...``
| uspace = `32`
| wordsep_re = `re.compile(r'`(`\s`+``|`%`|``[``^`\s\w`]``*`\w`+``[`a`-`zA`-`Z`]`-`(?=`\w`+``[`a`-``...``
| sentence_end_re = `re.compile(r'`[`abcdefghijklmnopqrstuvwxyz`]``[`\.`...``
| x = `32`

Method Details | [hide private]

### _munge_whitespace(self, text) | source code
    _munge_whitespace(text : string) -> string

            Munge whitespace in text: expand tabs and convert all other
            whitespace characters to spaces.  Eg. " foo     bar

    baz"
            becomes " foo    bar  baz".

### _split(self, text) | source code
    _split(text : string) -> [string]

    Split the text to wrap into indivisible chunks.  Chunks are
    not quite the same as words; see wrap_chunks() for full
    details.  As an example, the text
      Look, goof-ball -- use the -b option!
    breaks into the following chunks:
      'Look,', ' ', 'goof-', 'ball', ' ', '--', ' ',
      'use', ' ', 'the', ' ', '-b', ' ', 'option!'

### _fix_sentence_endings(self, chunks) | source code
    _fix_sentence_endings(chunks : [string])

            Correct for sentence endings buried in 'chunks'.  Eg. when the
            original text contains "... foo.
    Bar ...", munge_whitespace()
            and split() will convert that to [..., "foo.", " ", "Bar", ...]
            which has one too few spaces; this method simply changes the one
            space to two.

### _handle_long_word(self, reversed_chunks, cur_line, cur_len, width) | source code
    _handle_long_word(chunks : [string],
                         cur_line : [string],
                         cur_len : int, width : int)

    Handle a chunk of text (most likely a word, not whitespace) that
    is too long to fit in any line.

### _wrap_chunks(self, chunks) | source code
_wrap_chunks(chunks : [string]) -> [string] Wrap a sequence of text chunks and return a list of lines of length 'self.width' or less. (If 'break_long_words' is false, some lines may be longer than this.) Chunks correspond roughly to words and the whitespace between them: each chunk is indivisible (modulo 'break_long_words'), but a line break can come between any two chunks. Chunks should not have internal whitespace; ie. a chunk is either all whitespace or a "word". Whitespace chunks will be removed from the beginning and end of lines, but apart from that whitespace is preserved.

### wrap(self, text) | source code
wrap(text : string) -> [string] Reformat the single paragraph in 'text' so it fits in lines of no more than 'self.width' columns, and return a list of wrapped lines. Tabs in 'text' are expanded with string.expandtabs(), and all other whitespace characters (including newline) are converted to space.

### fill(self, text) | source code
fill(text : string) -> string Reformat the single paragraph in 'text' to fit in lines of no more than 'self.width' columns, and return a new string containing the entire wrapped paragraph.

Class Variable Details | [hide private]

  ### whitespace_trans Value:
      '\x00\x01\x02\x03\x04\x05\x06\x07\x08     \x0e\x0f\x10\x11\x12\x13\x14
      \x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x1f !"#$%&\'()*+,-./012345678
      9:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}
      ~\x7f\x80\x81\x82\x83\x84\x85\x86\x87\x88\x89\x8a\x8b\x8c\x8d\x8e\x8f\
      x90\x91\x92\x93\x94\x95\x96\x97\x98\x99\x9a\x9b\x9c\x9d\x9e\x9f\xa0\xa
      1\xa2\xa3\xa4\xa5\xa6\xa7\xa8\xa9\xaa\xab\xac\xad\xae\xaf\xb0\xb1\xb2\
      xb3\xb4\xb5\xb6\xb7\xb8\xb9\xba\xbb\xbc\xbd\xbe\xbf\xc0\xc1\xc2\xc3\xc
      4\xc5\xc6\xc7\xc8\xc9\xca\xcb\xcc\xcd\xce\xcf\xd0\xd1\xd2\xd3\xd4\xd5\
      ...

  ### unicode_whitespace_trans Value:
      {9: 32, 10: 32, 11: 32, 12: 32, 13: 32, 32: 32}

  ### wordsep_re Value:
      re.compile(r'(\s+|%|[^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|(?<=[\w!"\'&\.
      ,\?])-{2,}(?=\w))')

  ### sentence_end_re Value:
      re.compile(r'[abcdefghijklmnopqrstuvwxyz][\.!\?]["\']?')